"use strict";

/* eslint-disable no-console */

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/createContext(null);
export function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    const initHighlighter = async () => {
      try {
        if (!initialThemes.length) {
          throw new Error('At least one theme must be provided');
        }
        _log('Initializing with themes:', initialThemes.map(t => t.name));
        const highlighterInstance = await createHighlighterCore({
          themes: initialThemes,
          langs: initialLanguages,
          engine: createJavaScriptRegexEngine({
            forgiving: true,
            cache: new Map()
          })
        });

        // Set the first theme as default
        const defaultTheme = initialThemes[0];
        if (defaultTheme) {
          highlighterInstance.setTheme(defaultTheme);
          _log('Default theme set:', defaultTheme.name);
        }
        _log('Initialization complete', {
          languages: highlighterInstance.getLoadedLanguages(),
          themes: highlighterInstance.getLoadedThemes()
        });
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = useMemo(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map